<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="37"/>
        <location filename="../asciifile/asciifile.cpp" line="43"/>
        <source>Read ascii points</source>
        <translation>Ler puntos ASCII</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importar ESRI Shapefile</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Aliñar</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>Primeiro punto base:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>Primeiro punto de destino:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>Segundo punto base:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>Segundo punto de destino:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Listado de entidades</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Entidade baleira</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="73"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="75"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="76"/>
        <source>Line type</source>
        <translation>Tipo de liña</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Line thickness</source>
        <translation>Grosor de liña</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="78"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="84"/>
        <source>POINT</source>
        <translation>PUNTO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="85"/>
        <location filename="../list/list.cpp" line="195"/>
        <source>in point</source>
        <translation>no punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="90"/>
        <source>LINE</source>
        <translation>LIÑA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="95"/>
        <source>from point</source>
        <translation>dende o punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="98"/>
        <source>to point</source>
        <translation>ata o punto</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="103"/>
        <location filename="../list/list.cpp" line="127"/>
        <source>length</source>
        <translation>lonxitude</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="108"/>
        <source>Angle in XY plane</source>
        <translation>Ángulo no plano XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="109"/>
        <source>Inc.</source>
        <translation>Incremento</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="114"/>
        <source>ARC</source>
        <translation>ARCO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="115"/>
        <location filename="../list/list.cpp" line="131"/>
        <location filename="../list/list.cpp" line="141"/>
        <source>center point</source>
        <translation>centro</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="121"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="199"/>
        <source>radius</source>
        <translation>raio</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="122"/>
        <source>initial angle</source>
        <translation>ángulo inicial</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="123"/>
        <source>final angle</source>
        <translation>ángulo final</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="130"/>
        <source>CIRCLE</source>
        <translation>CÍRCULO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="136"/>
        <source>circumference</source>
        <translation>circunferencia</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="137"/>
        <source>area</source>
        <translation>área</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>ELLIPSE</source>
        <translation>ELIPSE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>major axis</source>
        <translation>eixe maior</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="162"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>LIÑA DE CONSTRUCIÓN</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="165"/>
        <source>OVERLAYBOX</source>
        <translation>CAIXA DE CUBRICIÓN</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="168"/>
        <source>SOLID</source>
        <translation>SÓLIDO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>MTEXT</source>
        <translation>TEXTO MULTILIÑA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="175"/>
        <source>TEXT</source>
        <translation>TEXTO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="178"/>
        <source>INSERT</source>
        <translation>OBXECTO INSERIDO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="181"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>Insertion point</source>
        <translation>Punto de inserción</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>POLYLINE</source>
        <translation>POLILIÑA</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="188"/>
        <source>Closed</source>
        <translation>Pechado</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Vertices</source>
        <translation>Vértices</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="204"/>
        <source>IMAGE</source>
        <translation>IMAXE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="207"/>
        <source>SPLINE</source>
        <translation>SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>SPLINEPOINTS</source>
        <translation>SPLINENODOS</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>HATCH</source>
        <translation>RAIADO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="216"/>
        <source>DIMLEADER</source>
        <translation>DIRECTRIZ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="219"/>
        <source>DIMALIGNED</source>
        <translation>ACOUTAMENTO ALIÑADO</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="222"/>
        <source>DIMLINEAR</source>
        <translation>ACOUTAMENTO LINEAR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="225"/>
        <source>DIMRADIAL</source>
        <translation>ACOUTAMENTO RADIAL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="228"/>
        <source>DIMDIAMETRIC</source>
        <translation>ACOUTAMENTO DIAMETRAL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="231"/>
        <source>DIMANGULAR</source>
        <translation>ACOUTAMENTO ANGULAR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="234"/>
        <source>UNKNOWN</source>
        <translation>DESCOÑECIDO</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Igualar &amp;atributos</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>Seleccionar obxecto orixinal:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>Seleccionar obxectos a trocar</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Plugin de mostra</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="38"/>
        <source>Read PIC file</source>
        <translation>Ler ficheiro PIC</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="44"/>
        <source>import PIC file</source>
        <translation>Importar ficheiro PIC</translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>Read ascii points</source>
        <translation>Ler puntos ASCII</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="241"/>
        <source>File...</source>
        <translation>Ficheiro...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="248"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space Separator</source>
        <translation>Separador espazo</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Tab Separator</source>
        <translation>Separador tabulador</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Comma Separator</source>
        <translation>Separador coma</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space in Columns</source>
        <translation>Espazo en columnas</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb para Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="252"/>
        <source>Connect points</source>
        <translation>Conectar puntos</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>2D Point</source>
        <translation>Punto 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>Draw 2D Point</source>
        <translation>Debuxar punto 2D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>3D Point</source>
        <translation>Punto 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>Draw 3D Point</source>
        <translation>Debuxar punto 3D</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Point Number</source>
        <translation>Número de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Draw point number</source>
        <translation>Debuxar número de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Point Elevation</source>
        <translation>Elevación de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Draw point elevation</source>
        <translation>Debuxar elevación de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Point Code</source>
        <translation>Referencia de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Draw point code</source>
        <translation>Debuxar referencia de punto</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="278"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="283"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="313"/>
        <source>Select file</source>
        <translation>Seleccionar ficheiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point 2D layer is empty</source>
        <translation>Capa en punto 2D está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="323"/>
        <source>Point 3D layer is empty</source>
        <translation>Capa en punto 3D está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point elevation layer is empty</source>
        <translation>Capa en elevación de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point elevation height is empty</source>
        <translation>Altitude en elevación de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="328"/>
        <source>Point elevation separation is empty</source>
        <translation>Separación en elevación de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point number layer is empty</source>
        <translation>Capa en número de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point number height is empty</source>
        <translation>Altitude en nùmero de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="333"/>
        <source>Point number separation is empty</source>
        <translation>Separación en número de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="336"/>
        <source>Point code layer is empty</source>
        <translation>Capa en referencia de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="337"/>
        <source>Point code height is empty</source>
        <translation>Altitude en referencia de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="338"/>
        <source>Point code separation is empty</source>
        <translation>Separación en referencia de punto está baleiro</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="366"/>
        <source>The file %1 not exist</source>
        <translation>O ficheiro %1 non existe</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="371"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Non se pode abrir o ficheiro %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Ficheiro...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Ficheiro tipo:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Importar ESRI Shapefile</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Descoñecido</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Dos datos:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Tipo de liña</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Grosor</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>Como punto</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>Como etiqueta:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Seleccionar ficheiro</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Punto+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>Punto 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Multipunto</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Multipunto+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>Multipunto 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Arco+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>Arco 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Polígono</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Polígono+Medida</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>Polígono 3D</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Mendo múltiple</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>O ficheiro %1 non ten extensión .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>O ficheiro %1 non existe</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>List entities</source>
        <translation>Listado de entidades</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Debuxar liña</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>X inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Y inicial:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>X final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Y final:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>X inicial está baleiro</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Y inicial está baleiro</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>X final está baleiro</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Y final está baleiro</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Plugin de mostra</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="67"/>
        <source>File...</source>
        <translation>Ficheiro...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="77"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="81"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="113"/>
        <source>Select file</source>
        <translation>Seleccionar ficheiro</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="121"/>
        <source>Scale Factor is empty or invalid</source>
        <translation>Factor de Escala está baleiro ou non é válido</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="134"/>
        <source>The file %1 not exist</source>
        <translation>O ficheiro %1 non existe</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="139"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Non se pode abrir o ficheiro %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="146"/>
        <source>%1 objects imported</source>
        <translation>%1 obxectos importados</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="168"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation>picPunto drawLine: o primeiro punto está baleiro %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="181"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation>picPunto drawLine: o segundo punto está baleiro %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="260"/>
        <location filename="../picfile/picfile.cpp" line="269"/>
        <source>format error in %1</source>
        <translation>erro de formato en %1</translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>Plugin de trazado</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">Debuxar</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>Trazar ecuación</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Este plugin permítelle trazar ecuacións matemáticas.
Se non quere empregar a forma paramétrica, deixe sen cubrir &quot;Ecuación2&quot;.
Pode empregar pi cando precise o valor de pi (ex. (3 *pi)).
Use t ou x na súa ecuación como unha variable/parámetro.
</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Ecuación 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Ecuación 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>Valor inicial:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>Valor final:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>Distancia de paso:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Debuxar</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>Segmentos de liña</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>Poliliña</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation>Spline por Puntos</translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="177"/>
        <source>Layer:</source>
        <translation>Capa:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="210"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="211"/>
        <source>Height:</source>
        <translation>Altitude:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="212"/>
        <source>Separation</source>
        <translation>Separación</translation>
    </message>
</context>
</TS>
